@@ -1,6 +1,6 @@
 package Plack::Middleware::Debug::Dancer::Session;
 BEGIN {
-  $Plack::Middleware::Debug::Dancer::Session::VERSION = '0.01';
+  $Plack::Middleware::Debug::Dancer::Session::VERSION = '0.02';
 }
 
 # ABSTRACT: Session panel for your Dancer's application
@@ -24,6 +24,7 @@ sub run {
 
 1;
 
+
 __END__
 =pod
 
@@ -33,11 +34,21 @@ Plack::Middleware::Debug::Dancer::Session - Session panel for your Dancer's appl
 
 =head1 VERSION
 
-version 0.01
+version 0.02
+
+=head1 SYNOPSIS
+
+To activate this panel:
+
+    plack_middlewares:
+      Debug:
+        - panels
+        -
+          - Dancer::Session
 
 =head1 AUTHOR
 
-  franck cuny <franck@lumberjaph.net>
+franck cuny <franck@lumberjaph.net>
 
 =head1 COPYRIGHT AND LICENSE
 
